@@ -546,6 +546,17 @@ RM_STATUS NV_API_CALL os_flush_cpu_cache(void)
 }
 #endif
 
+RM_STATUS NV_API_CALL os_flush_user_cache(
+    NvU64 start,
+    NvU64 end,
+    NvU64 physStart,
+    NvU64 physEnd, 
+    NvU32 flags
+)
+{
+    return RM_ERR_NOT_SUPPORTED;
+}
+
 static void sfence_action_func(void *arg)
 {
     __asm__ __volatile__("sfence": : :"memory");
