@@ -91,17 +91,18 @@ RM_STATUS   NV_API_CALL  os_memcpy_to_user           (void *, const void *, NvU3
 void*       NV_API_CALL  os_mem_set                  (void *, NvU8, NvU32);
 NvS32       NV_API_CALL  os_mem_cmp                  (const NvU8 *, const NvU8 *, NvU32);
 void*       NV_API_CALL  os_pci_init_handle          (NvU32, NvU8, NvU8, NvU8, NvU16 *, NvU16 *);
-NvU8        NV_API_CALL  os_pci_read_byte            (void *, NvU8);
-NvU16       NV_API_CALL  os_pci_read_word            (void *, NvU8);
-NvU32       NV_API_CALL  os_pci_read_dword           (void *, NvU8);
-void        NV_API_CALL  os_pci_write_byte           (void *, NvU8, NvU8);
-void        NV_API_CALL  os_pci_write_word           (void *, NvU8, NvU16);
-void        NV_API_CALL  os_pci_write_dword          (void *, NvU8, NvU32);
+RM_STATUS   NV_API_CALL  os_pci_read_byte            (void *, NvU32, NvU8 *);
+RM_STATUS   NV_API_CALL  os_pci_read_word            (void *, NvU32, NvU16 *);
+RM_STATUS   NV_API_CALL  os_pci_read_dword           (void *, NvU32, NvU32 *);
+RM_STATUS   NV_API_CALL  os_pci_write_byte           (void *, NvU32, NvU8);
+RM_STATUS   NV_API_CALL  os_pci_write_word           (void *, NvU32, NvU16);
+RM_STATUS   NV_API_CALL  os_pci_write_dword          (void *, NvU32, NvU32);
 void*       NV_API_CALL  os_map_kernel_space         (NvU64, NvU64, NvU32);
 void        NV_API_CALL  os_unmap_kernel_space       (void *, NvU64);
 void*       NV_API_CALL  os_map_user_space           (NvU64, NvU64, NvU32, NvU32, void **);
 void        NV_API_CALL  os_unmap_user_space         (void *, NvU64, void *);
 RM_STATUS   NV_API_CALL  os_flush_cpu_cache          (void);
+RM_STATUS   NV_API_CALL  os_flush_user_cache         (NvU64, NvU64, NvU64, NvU64, NvU32);
 void        NV_API_CALL  os_flush_cpu_write_combine_buffer(void);
 RM_STATUS   NV_API_CALL  os_set_mem_range            (NvU64, NvU64, NvU32);
 RM_STATUS   NV_API_CALL  os_unset_mem_range          (NvU64, NvU64);
@@ -222,6 +223,10 @@ void NV_API_CALL  nv_prints(NvU32 debuglevel, const char *string);
 #define NV_PROTECT_WRITEABLE  2
 #define NV_PROTECT_READ_WRITE (NV_PROTECT_READABLE | NV_PROTECT_WRITEABLE)
 
+#define NV_FLUSH_USER_CACHE       1
+#define NV_INVALIDATE_USER_CACHE  2
+#define NV_FLUSH_INVALIDATE_USER_CACHE (NV_FLUSH_USER_CACHE | NV_INVALIDATE_USER_CACHE)
+
 /* in some cases, the os may have a different page size, but the
  * hardware (fb, regs, etc) still address and "think" in 4k
  * pages. make sure we can mask and twiddle with these addresses when
