@@ -87,7 +87,7 @@ typedef NvU32 RM_STATUS;
 #define RM_ERR_I2C_ERROR                0x0000003B
 #define RM_ERR_FREQ_NOT_SUPPORTED       0x0000003C
 #define RM_ERR_INVALID_REQUEST          0x0000003D
-#define RM_ERR_MORE_PROCESSING_REQUIRED 0x0000003E
+#define RM_ERR_MORE_PROCESSING_REQUIRED 0x0000003E      // warning in most cases
 #define RM_ERR_MISSING_TABLE_ENTRY      0x0000003F
 #define RM_ERR_NO_INTR_PENDING          0x00000040
 #define RM_ERR_INSUFFICIENT_PERMISSIONS 0x00000041
@@ -105,8 +105,16 @@ typedef NvU32 RM_STATUS;
 #define RM_ERR_INVALID_IRQ_LEVEL        0x00000051
 #define RM_ERR_BUSY_RETRY               0x00000052
 
+#define RM_ERR_INVALID_PATH             0x00000060
+#define RM_ERR_CANT_HOT_SWITCH          0x00000061
+#define RM_ERR_MISMATCHED_TARGET        0x00000062
+#define RM_ERR_OUT_OF_RANGE             0x00000063
+#define RM_ERR_NO_VALID_PATH            0x00000064
+#define RM_ERR_CONSTRAINT_VIOLATION     0x00000065
+
 // Warnings:
 #define RM_WARN_NULL_OBJECT             0x00000100
 #define RM_WARN_INCORRECT_PERFMON_DATA  0x00000101
+#define RM_WARN_NOTHING_TO_DO           0x00000102
 
 #endif /* _RMRETVAL_H_ */
